@@ -4,9 +4,9 @@
  * Gnome Crystal
  * atom.h 
  *
- * Copyright (C) 2000-2003
+ * Copyright (C) 2000-2004
  *
- * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Brfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -31,7 +31,11 @@
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
-#include <crystalviewer/crystalatom.h>
+#ifdef GCU_OLD_VER
+#	include <crystalviewer/crystalatom.h>
+#else
+#	include <gcu/crystalatom.h>
+#endif
 
 using namespace gcu;
 
